@@ -17,27 +17,27 @@
 #
 # Unit tests for cinder::backup:glusterfs class
 #
-
 require 'spec_helper'
 
 describe 'cinder::backup::glusterfs' do
-
   let :default_params do
-    { :glusterfs_backup_mount_point => '<SERVICE DEFAULT>',
-      :glusterfs_backup_share       => '<SERVICE DEFAULT>' }
+    {
+      :glusterfs_backup_mount_point => '<SERVICE DEFAULT>',
+      :glusterfs_backup_share       => '<SERVICE DEFAULT>'
+    }
   end
 
   let :params do
     {}
   end
 
-  shared_examples_for 'cinder backup with glusterfs' do
+  shared_examples 'cinder backup with glusterfs' do
     let :p do
       default_params.merge(params)
     end
 
     it 'configures cinder.conf' do
-      is_expected.to contain_cinder_config('DEFAULT/backup_driver').with_value('cinder.backup.drivers.glusterfs')
+      is_expected.to contain_cinder_config('DEFAULT/backup_driver').with_value('cinder.backup.drivers.glusterfs.GlusterfsBackupDriver')
       is_expected.to contain_cinder_config('DEFAULT/glusterfs_backup_mount_point').with_value(p[:glusterfs_backup_mount_point])
       is_expected.to contain_cinder_config('DEFAULT/glusterfs_backup_share').with_value(p[:glusterfs_backup_share])
     end
@@ -62,8 +62,7 @@ describe 'cinder::backup::glusterfs' do
         facts.merge(OSDefaults.get_facts({:os_workers => 8}))
       end
 
-      it_configures 'cinder backup with glusterfs'
+      it_behaves_like 'cinder backup with glusterfs'
     end
   end
-
 end
