@@ -17,13 +17,12 @@
 #
 # Unit tests for cinder::backup::google class
 #
-
 require 'spec_helper'
 
 describe 'cinder::backup::google' do
-
   let :default_params do
-    { :backup_gcs_bucket                => '<SERVICE DEFAULT>',
+    {
+      :backup_gcs_bucket                => '<SERVICE DEFAULT>',
       :backup_gcs_object_size           => '<SERVICE DEFAULT>',
       :backup_gcs_block_size            => '<SERVICE DEFAULT>',
       :backup_gcs_reader_chunk_size     => '<SERVICE DEFAULT>',
@@ -35,20 +34,21 @@ describe 'cinder::backup::google' do
       :backup_gcs_credential_file       => '<SERVICE DEFAULT>',
       :backup_gcs_project_id            => '<SERVICE DEFAULT>',
       :backup_gcs_user_agent            => '<SERVICE DEFAULT>',
-      :backup_gcs_enable_progress_timer => '<SERVICE DEFAULT>' }
+      :backup_gcs_enable_progress_timer => '<SERVICE DEFAULT>'
+    }
   end
 
   let :params do
     {}
   end
 
-  shared_examples_for 'cinder backup with google cloud storage' do
+  shared_examples 'cinder backup with google cloud storage' do
     let :p do
       default_params.merge(params)
     end
 
     it 'configures cinder.conf' do
-      is_expected.to contain_cinder_config('DEFAULT/backup_driver').with_value('cinder.backup.drivers.google')
+      is_expected.to contain_cinder_config('DEFAULT/backup_driver').with_value('cinder.backup.drivers.google.GoogleBackupDriver')
       is_expected.to contain_cinder_config('DEFAULT/backup_gcs_bucket').with_value(p[:backup_gcs_bucket])
       is_expected.to contain_cinder_config('DEFAULT/backup_gcs_object_size').with_value(p[:backup_gcs_object_size])
       is_expected.to contain_cinder_config('DEFAULT/backup_gcs_block_size').with_value(p[:backup_gcs_block_size])
@@ -106,8 +106,7 @@ describe 'cinder::backup::google' do
         facts.merge(OSDefaults.get_facts({:os_workers => 8}))
       end
 
-      it_configures 'cinder backup with google cloud storage'
+      it_behaves_like 'cinder backup with google cloud storage'
     end
   end
-
 end
