@@ -1,7 +1,6 @@
 require 'spec_helper'
 
 describe 'cinder::logging' do
-
   let :params do
     {
     }
@@ -11,29 +10,30 @@ describe 'cinder::logging' do
     {
       :logging_context_format_string => '%(asctime)s.%(msecs)03d %(process)d %(levelname)s %(name)s [%(request_id)s %(user_identity)s] %(instance)s%(message)s',
       :logging_default_format_string => '%(asctime)s.%(msecs)03d %(process)d %(levelname)s %(name)s [-] %(instance)s%(message)s',
-      :logging_debug_format_suffix => '%(funcName)s %(pathname)s:%(lineno)d',
-      :logging_exception_prefix => '%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s %(instance)s',
-      :log_config_append => '/etc/cinder/logging.conf',
-      :publish_errors => true,
-      :default_log_levels => {
+      :logging_debug_format_suffix   => '%(funcName)s %(pathname)s:%(lineno)d',
+      :logging_exception_prefix      => '%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s %(instance)s',
+      :log_config_append             => '/etc/cinder/logging.conf',
+      :publish_errors                => true,
+      :default_log_levels            => {
         'amqp' => 'WARN', 'amqplib' => 'WARN', 'boto' => 'WARN',
         'sqlalchemy' => 'WARN', 'suds' => 'INFO', 'iso8601' => 'WARN',
         'requests.packages.urllib3.connectionpool' => 'WARN' },
-     :fatal_deprecations => true,
-     :instance_format => '[instance: %(uuid)s] ',
-     :instance_uuid_format => '[instance: %(uuid)s] ',
-     :log_date_format => '%Y-%m-%d %H:%M:%S',
-     :use_syslog => true,
-     :use_json => true,
-     :use_journal => true,
-     :use_stderr => false,
-     :log_facility => 'LOG_FOO',
-     :log_dir => '/var/log',
-     :debug => true,
+     :fatal_deprecations             => true,
+     :instance_format                => '[instance: %(uuid)s] ',
+     :instance_uuid_format           => '[instance: %(uuid)s] ',
+     :log_date_format                => '%Y-%m-%d %H:%M:%S',
+     :use_syslog                     => true,
+     :use_json                       => true,
+     :use_journal                    => true,
+     :use_stderr                     => false,
+     :log_facility                   => 'LOG_FOO',
+     :log_dir                        => '/var/log',
+     :log_file                       => '/var/log/cinder/cinder.log',
+     :debug                          => true,
     }
   end
 
-  shared_examples_for 'cinder-logging' do
+  shared_examples 'cinder-logging' do
 
     context 'with basic logging options and default settings' do
       it_behaves_like  'basic default logging settings'
@@ -63,6 +63,7 @@ describe 'cinder::logging' do
         :use_journal => '<SERVICE DEFAULT>',
         :use_stderr  => '<SERVICE DEFAULT>',
         :log_dir     => '/var/log/cinder',
+        :log_file    => '<SERVICE DEFAULT>',
         :debug       => '<SERVICE DEFAULT>',
       )
     end
@@ -77,12 +78,13 @@ describe 'cinder::logging' do
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
+        :log_file            => '/var/log/cinder/cinder.log',
         :debug               => true,
       )
     end
   end
 
-  shared_examples_for 'logging params set' do
+  shared_examples 'logging params set' do
     it 'enables logging params' do
       is_expected.to contain_oslo__log('cinder_config').with(
         :logging_context_format_string =>
@@ -104,7 +106,7 @@ describe 'cinder::logging' do
     end
   end
 
-  shared_examples_for 'logging params unset' do
+  shared_examples 'logging params unset' do
    [ :logging_context_format_string, :logging_default_format_string,
      :logging_debug_format_suffix, :logging_exception_prefix,
      :log_config_append, :publish_errors,
@@ -126,5 +128,4 @@ describe 'cinder::logging' do
       it_behaves_like 'cinder-logging'
     end
   end
-
 end
